@@ -152,17 +152,6 @@ class OpenLineageListener:
             return
 
         # Needs to be calculated outside of inner method so that it gets cached for usage in fork processes
-        data_interval_start = dagrun.data_interval_start
-        if isinstance(data_interval_start, datetime):
-            data_interval_start = data_interval_start.isoformat()
-        data_interval_end = dagrun.data_interval_end
-        if isinstance(data_interval_end, datetime):
-            data_interval_end = data_interval_end.isoformat()
-
-        clear_number = 0
-        if hasattr(dagrun, "clear_number"):
-            clear_number = dagrun.clear_number
-
         debug_facet = get_airflow_debug_facet()
 
         @print_warning(self.log)
@@ -176,6 +165,10 @@ class OpenLineageListener:
             if AIRFLOW_V_3_0_PLUS and date is None:
                 date = dagrun.run_after
 
+            clear_number = 0
+            if hasattr(dagrun, "clear_number"):
+                clear_number = dagrun.clear_number
+
             parent_run_id = self.adapter.build_dag_run_id(
                 dag_id=dag.dag_id,
                 logical_date=date,
@@ -192,6 +185,13 @@ class OpenLineageListener:
             event_type = RunState.RUNNING.value.lower()
             operator_name = task.task_type.lower()
 
+            data_interval_start = dagrun.data_interval_start
+            if isinstance(data_interval_start, datetime):
+                data_interval_start = data_interval_start.isoformat()
+            data_interval_end = dagrun.data_interval_end
+            if isinstance(data_interval_end, datetime):
+                data_interval_end = data_interval_end.isoformat()
+
             with Stats.timer(f"ol.extract.{event_type}.{operator_name}"):
                 task_metadata = self.extractor_manager.extract_metadata(
                     dagrun=dagrun, task=task, task_instance_state=TaskInstanceState.RUNNING
@@ -202,10 +202,11 @@ class OpenLineageListener:
                 job_name=get_job_name(task),
                 job_description=dag.description,
                 event_time=start_date.isoformat(),
-                code_location=None,
                 nominal_start_time=data_interval_start,
                 nominal_end_time=data_interval_end,
-                owners=dag.owner.split(", "),
+                # If task owner is default ("airflow"), use DAG owner instead that may have more details
+                owners=[x.strip() for x in (task if task.owner != "airflow" else dag).owner.split(",")],
+                tags=dag.tags,
                 task=task_metadata,
                 run_facets={
                     **get_task_parent_run_facet(parent_run_id=parent_run_id, parent_job_name=dag.dag_id),
@@ -303,6 +304,13 @@ class OpenLineageListener:
             event_type = RunState.COMPLETE.value.lower()
             operator_name = task.task_type.lower()
 
+            data_interval_start = dagrun.data_interval_start
+            if isinstance(data_interval_start, datetime):
+                data_interval_start = data_interval_start.isoformat()
+            data_interval_end = dagrun.data_interval_end
+            if isinstance(data_interval_end, datetime):
+                data_interval_end = data_interval_end.isoformat()
+
             with Stats.timer(f"ol.extract.{event_type}.{operator_name}"):
                 task_metadata = self.extractor_manager.extract_metadata(
                     dagrun=dagrun,
@@ -316,6 +324,11 @@ class OpenLineageListener:
                 job_name=get_job_name(task),
                 end_time=end_date.isoformat(),
                 task=task_metadata,
+                # If task owner is default ("airflow"), use DAG owner instead that may have more details
+                owners=[x.strip() for x in (task if task.owner != "airflow" else dag).owner.split(",")],
+                tags=dag.tags,
+                nominal_start_time=data_interval_start,
+                nominal_end_time=data_interval_end,
                 run_facets={
                     **get_task_parent_run_facet(parent_run_id=parent_run_id, parent_job_name=dag.dag_id),
                     **get_user_provided_run_facets(task_instance, TaskInstanceState.SUCCESS),
@@ -422,6 +435,13 @@ class OpenLineageListener:
             event_type = RunState.FAIL.value.lower()
             operator_name = task.task_type.lower()
 
+            data_interval_start = dagrun.data_interval_start
+            if isinstance(data_interval_start, datetime):
+                data_interval_start = data_interval_start.isoformat()
+            data_interval_end = dagrun.data_interval_end
+            if isinstance(data_interval_end, datetime):
+                data_interval_end = data_interval_end.isoformat()
+
             with Stats.timer(f"ol.extract.{event_type}.{operator_name}"):
                 task_metadata = self.extractor_manager.extract_metadata(
                     dagrun=dagrun,
@@ -436,6 +456,11 @@ class OpenLineageListener:
                 end_time=end_date.isoformat(),
                 task=task_metadata,
                 error=error,
+                nominal_start_time=data_interval_start,
+                nominal_end_time=data_interval_end,
+                tags=dag.tags,
+                # If task owner is default ("airflow"), use DAG owner instead that may have more details
+                owners=[x.strip() for x in (task if task.owner != "airflow" else dag).owner.split(",")],
                 run_facets={
                     **get_task_parent_run_facet(parent_run_id=parent_run_id, parent_job_name=dag.dag_id),
                     **get_user_provided_run_facets(task_instance, TaskInstanceState.FAILED),
@@ -605,6 +630,7 @@ class OpenLineageListener:
                 clear_number=dag_run.clear_number,
                 owners=[x.strip() for x in dag_run.dag.owner.split(",")] if dag_run.dag else None,
                 description=dag_run.dag.description if dag_run.dag else None,
+                tags=dag_run.dag.tags if dag_run.dag else [],
                 # AirflowJobFacet should be created outside ProcessPoolExecutor that pickles objects,
                 # as it causes lack of some TaskGroup attributes and crashes event emission.
                 job_facets=get_airflow_job_facet(dag_run=dag_run),
@@ -634,13 +660,22 @@ class OpenLineageListener:
             if AIRFLOW_V_3_0_PLUS and date is None:
                 date = dag_run.run_after
 
+            data_interval_start = (
+                dag_run.data_interval_start.isoformat() if dag_run.data_interval_start else None
+            )
+            data_interval_end = dag_run.data_interval_end.isoformat() if dag_run.data_interval_end else None
+
             self.submit_callable(
                 self.adapter.dag_success,
                 dag_id=dag_run.dag_id,
                 run_id=dag_run.run_id,
                 end_date=dag_run.end_date,
+                nominal_start_time=data_interval_start,
+                nominal_end_time=data_interval_end,
                 logical_date=date,
                 clear_number=dag_run.clear_number,
+                owners=[x.strip() for x in dag_run.dag.owner.split(",")] if dag_run.dag else None,
+                tags=dag_run.dag.tags if dag_run.dag else [],
                 task_ids=task_ids,
                 dag_run_state=dag_run.get_state(),
                 run_facets={**get_airflow_dag_run_facet(dag_run)},
@@ -670,13 +705,22 @@ class OpenLineageListener:
             if AIRFLOW_V_3_0_PLUS and date is None:
                 date = dag_run.run_after
 
+            data_interval_start = (
+                dag_run.data_interval_start.isoformat() if dag_run.data_interval_start else None
+            )
+            data_interval_end = dag_run.data_interval_end.isoformat() if dag_run.data_interval_end else None
+
             self.submit_callable(
                 self.adapter.dag_failed,
                 dag_id=dag_run.dag_id,
                 run_id=dag_run.run_id,
                 end_date=dag_run.end_date,
+                nominal_start_time=data_interval_start,
+                nominal_end_time=data_interval_end,
                 logical_date=date,
                 clear_number=dag_run.clear_number,
+                owners=[x.strip() for x in dag_run.dag.owner.split(",")] if dag_run.dag else None,
+                tags=dag_run.dag.tags if dag_run.dag else [],
                 dag_run_state=dag_run.get_state(),
                 task_ids=task_ids,
                 msg=msg,
